Crate serenity_voice_model

Crate serenity_voice_model 

Mappings of objects received from Discord’s voice gateway API, with implementations for (de)serialisation.

Re-exports

pub use self::binary::BinaryError;
pub use self::binary::deserialize_binary_event;
pub use self::binary::serialize_binary_event;

Modules

binary
Binary serialization/deserialization for DAVE protocol opcodes.
constants
A set of constants used by the library.
id
A collection of newtypes defining type-strong IDs.
payload
Message bodies used in gateway event-handling.

Structs

ProtocolData
The client’s response to a connection offer.
SpeakingState
Flag set describing how a speaker is sending audio.

Enums

CloseCode
Discord Voice Gateway Websocket close codes.
Event
A representation of data received for voice gateway events.
Opcode
An enum representing the voice opcodes.

Traits

FromPrimitive
A generic trait for converting a number to a value.